# Generated by Django 4.2.8 on 2023-12-27 12:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_admin_keycloak", "0001_initial"),
    ]

    operations = [
        migrations.RenameField(
            model_name="keycloakprovider",
            old_name="client_secret_key",
            new_name="client_secret",
        ),
        migrations.AddField(
            model_name="keycloakprovider",
            name="is_static",
            field=models.BooleanField(
                default=False, editable=False, verbose_name="is static"
            ),
        ),
        migrations.AddField(
            model_name="keycloakprovider",
            name="scope",
            field=models.TextField(default="openid profile", verbose_name="scope"),
        ),
    ]
