# Generated by Django 4.2.8 on 2024-01-04 09:15

import django.contrib.sessions.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "django_admin_keycloak",
            "0002_rename_client_secret_key_keycloakprovider_client_secret_and_more",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="KeycloakSession",
            fields=[
                (
                    "session_key",
                    models.CharField(
                        max_length=40,
                        primary_key=True,
                        serialize=False,
                        verbose_name="session key",
                    ),
                ),
                ("session_data", models.TextField(verbose_name="session data")),
                (
                    "expire_date",
                    models.DateTimeField(db_index=True, verbose_name="expire date"),
                ),
                ("sid", models.UUIDField(null=True)),
            ],
            options={
                "verbose_name": "session",
                "verbose_name_plural": "sessions",
                "db_table": "keycloak_session",
                "abstract": False,
            },
            managers=[
                ("objects", django.contrib.sessions.models.SessionManager()),
            ],
        ),
    ]
